package com.ruoyi.project.zjsgfa.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.project.zjsgfa.domain.SjFdsgcsZjyFdxnb;

/**
 * 设计信息-分段施工措施-分段钻井液性能设计Service接口
 * 
 * @author ruoyi
 * @date 2025-08-20
 */
public interface ISjFdsgcsZjyFdxnbService 
{
    /**
     * 查询设计信息-分段施工措施-分段钻井液性能设计
     * 
     * @param id 设计信息-分段施工措施-分段钻井液性能设计主键
     * @return 设计信息-分段施工措施-分段钻井液性能设计
     */
    public SjFdsgcsZjyFdxnb selectSjFdsgcsZjyFdxnbById(Long id);

    /**
     * 查询设计信息-分段施工措施-分段钻井液性能设计列表
     * 
     * @param sjFdsgcsZjyFdxnb 设计信息-分段施工措施-分段钻井液性能设计
     * @return 设计信息-分段施工措施-分段钻井液性能设计集合
     */
    public Map<String, Object> selectSjFdsgcsZjyFdxnbList(SjFdsgcsZjyFdxnb sjFdsgcsZjyFdxnb);

    /**
     * 新增设计信息-分段施工措施-分段钻井液性能设计
     * 
     * @param sjFdsgcsZjyFdxnb 设计信息-分段施工措施-分段钻井液性能设计
     * @return 结果
     */
    public int insertSjFdsgcsZjyFdxnb(SjFdsgcsZjyFdxnb sjFdsgcsZjyFdxnb);

    /**
     * 修改设计信息-分段施工措施-分段钻井液性能设计
     * 
     * @param sjFdsgcsZjyFdxnb 设计信息-分段施工措施-分段钻井液性能设计
     * @return 结果
     */
    public int updateSjFdsgcsZjyFdxnb(SjFdsgcsZjyFdxnb sjFdsgcsZjyFdxnb);

    /**
     * 批量删除设计信息-分段施工措施-分段钻井液性能设计
     * 
     * @param ids 需要删除的设计信息-分段施工措施-分段钻井液性能设计主键集合
     * @return 结果
     */
    public int deleteSjFdsgcsZjyFdxnbByIds(Long[] ids);

    /**
     * 删除设计信息-分段施工措施-分段钻井液性能设计信息
     * 
     * @param id 设计信息-分段施工措施-分段钻井液性能设计主键
     * @return 结果
     */
    public int deleteSjFdsgcsZjyFdxnbById(Long id);
}
